% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/017_maj_udir_ln.R
\name{maj_udir_ln}
\alias{maj_udir_ln}
\alias{maj_udir_ln.default}
\alias{maj_udir_ln.formula}
\title{Majority-class unidirectional label noise}
\usage{
\method{maj_udir_ln}{default}(x, y, level, sortid = TRUE, ...)

\method{maj_udir_ln}{formula}(formula, data, ...)
}
\arguments{
\item{x}{a data frame of input attributes.}

\item{y}{a factor vector with the output class of each sample.}

\item{level}{a double in [0,1] with the noise level to be introduced.}

\item{sortid}{a logical indicating if the indices must be sorted at the output (default: \code{TRUE}).}

\item{...}{other options to pass to the function.}

\item{formula}{a formula with the output class and, at least, one input attribute.}

\item{data}{a data frame in which to interpret the variables in the formula.}
}
\value{
An object of class \code{ndmodel} with elements:
\item{xnoise}{a data frame with the noisy input attributes.}
\item{ynoise}{a factor vector with the noisy output class.}
\item{numnoise}{an integer vector with the amount of noisy samples per class.}
\item{idnoise}{an integer vector list with the indices of noisy samples.}
\item{numclean}{an integer vector with the amount of clean samples per class.}
\item{idclean}{an integer vector list with the indices of clean samples.}
\item{distr}{an integer vector with the samples per class in the original data.}
\item{model}{the full name of the noise introduction model used.}
\item{param}{a list of the argument values.}
\item{call}{the function call.}
}
\description{
Introduction of \emph{Majority-class unidirectional label noise} into a classification dataset.
}
\details{
Let \emph{A} be the majority class and \emph{B} be the second majority class in the dataset.
The \emph{Majority-class unidirectional label noise} introduction model randomly selects (\code{level}·100)\% of the samples
of \emph{A} and labels them as \emph{B}.
}
\note{
Noise model adapted from the papers in References to multiclass data.
}
\examples{
# load the dataset
data(iris2D)

# usage of the default method
set.seed(9)
outdef <- maj_udir_ln(x = iris2D[,-ncol(iris2D)], y = iris2D[,ncol(iris2D)], level = 0.1)

# show results
summary(outdef, showid = TRUE)
plot(outdef)

# usage of the method for class formula
set.seed(9)
outfrm <- maj_udir_ln(formula = Species ~ ., data = iris2D, level = 0.1)

# check the match of noisy indices
identical(outdef$idnoise, outfrm$idnoise)

}
\references{
J. Li, Q. Zhu, Q. Wu, Z. Zhang, Y. Gong, Z. He, and F. Zhu. 
\strong{SMOTE- NaN-DE: Addressing the noisy and borderline examples problem in imbalanced 
classification by natural neighbors and differential evolution}. 
\emph{Knowledge-Based Systems}, 223:107056, 2021.
\doi{10.1016/j.knosys.2021.107056}.
}
\seealso{
\code{\link{asy_def_ln}}, \code{\link{print.ndmodel}}, \code{\link{summary.ndmodel}}, \code{\link{plot.ndmodel}}
}
